/*
 * @file    bmehal.h: BME hardware abstractions
 *
 * @author  <aliaksei.katovich at nokia.com>
 *
 * @date    Created: Tue Oct 13 16:11:05 EEST 2009
 *
 * Copyright (C) 2009 Nokia. All rights reserved.
 *
 */

#ifndef __BMEHAL_H__
#define __BMEHAL_H__

/*----------------- BME HAL constants -----------------*/

enum {
	BMEHAL_GROUP_HEAD = 0x7fff,
	/* charge state constants */
	CHARGE_STATE_ERROR,
	CHARGE_STATE_HWINIT,   /* 01 */
	CHARGE_STATE_DISABLE,  /* 02 */
	CHARGE_STATE_ENABLE,
	CHARGE_STATE_SUSPEND,
	CHARGE_STATE_START,    /* 05 */
	CHARGE_STATE_STOP,
	CHARGE_STATE_PAUSE,
	CHARGE_STATE_TIMEOUT,

	/* charge mode constants */
	CHARGE_MODE_NONE,
	CHARGE_MODE_100MA,
	CHARGE_MODE_500MA,
	CHARGE_MODE_WALL,      /* 0c */
	CHARGE_MODE_DYNAMO,

	/* charge control constants */
	/* set */
	CHARGE_SET_CURRENT, /* 0e */	/* set charge current */
	CHARGE_SET_VOLTAGE,		/* set charge voltage */
	CHARGE_SET_TERMINATION_CURRENT,	/* set termination current */
	CHARGE_SET_C100MA,		/* set 100mA current */
	CHARGE_SET_C500MA,		/* set 500mA current */
	CHARGE_SET_CINPUT,		/* set input current */
	CHARGE_SET_LEDCTL,		/* set led control */
	/* get */
	CHARGE_GET_VOLTAGE,
	CHARGE_GET_MODE,      /* 15 */
	CHARGE_GET_PINSTAT,		/* get current */

	/* charge timer */
	GET_CHARGE_TIMER_INTERVAL,      /* get the timer interval */
	CHARGE_TIMER,                   /* handle the timer event */

	/* charge status */
	CHARGE_STATUS_OFF,          /* Not charging                        */
	CHARGE_STATUS_CHARGING,     /* Charging with max current enabled   */
	CHARGE_STATUS_CHARGE_READY, /* Charge ready and terminated         */
	CHARGE_STATUS_ERROR,        /* An error occurred, charging stopped */

	/* battery controls */
	BATTERY_STATE_ENABLE,
	BATTERY_STATE_DISABLE,

	/* get */
	BATTERY_GET_INFO,               /* get pointer to bme_batinfo_t */
	BATTERY_GET_BSI,                /* get current battery BSI */

	/* ADC data controls */
	ADC_READ_DATA,
	ADC_WRITE_DATA,
	ADC_FLUSH_DATA,
	ADC_CHECK_DATA,
	ADC_DEFAULT_DATA,
	ADC_CURRENT_DATA,
	/* ADC read controls */
	ADC_READ_RAW,
	ADC_READ_RAW_AVG,
	ADC_READ_UNIT,
	ADC_READ_UNIT_AVG,
	ADC_READ_UNIT_MED,		/* read median value */
	/* ADC get controls*/
	ADC_GET_CHANNEL,		/* get channel mapping */
	ADC_GET_CHANNELS,		/* get channels number */
	ADC_GET_CURRENT_EVENT,          /* has current event occurred */
	/* ADC set controls*/
	ADC_SET_AMOUNT,			/* set amount of readings/writings */
	ADC_SET_CURRENT_EVENT,          /* set the current event mA limit */

	CHARGE_MODE_900MA,

	ADC_READ_GROUP,                 /* see struct bmeadc_group_read */
	CHARGE_STATE_RESET,

	BMEHAL_GROUP_TAIL,
};

#define	EBADBSI		-2

#endif /* __BMEHAL_H__ */
